Welcome to TRANSIT’s documentation! — TRANSIT v2.3.2 documentation

# Welcome to TRANSIT’s documentation!

This page contains the documentation for TRANSIT. Below are a few quick links to some of the most important sections of the documentation, followed by a brief overview of TRANSIT’s features.

## Quick Links

- Installation
- TRANSIT Manual
- tutorial-link
- TPP Manual
- Code Documentation

## Features

TRANSIT offers a variety of features including:

- More than 8 analysis methods, including methods for determining conditional essentiality as well as genetic interactions.
- Ability to analyze himar1 or tn5 transposons datasets.
- TrackView to help visualize read-counts accross the genome.
- Can export datasets into a variety of formats, including IGV.
- Includes a variety of normalization methods.
- Quality Control diagnostics, to idenfity poor quality datasets.
- Ability to install as a python package, to import and use in your own personal scripts.

## Mailing List

You can join our mailing list to get announcements of new versions, discuss any bugs, or request features! Just head over to the following site and enter your email address:

> - https://groups.google.com/forum/#!forum/tnseq-transit/join

TRANSIT Manual

- TRANSIT Overview
  - Tn5 Datasets
  - Developers
  - References
- Installation
  - Requirements
  - Use as a Python Package
  - Optional: Install BWA to use with TPP pre-processor
  - Upgrading
  - Installing wxPython
  - Troubleshooting
- Running TRANSIT
  - GUI Mode
  - Command line Mode
- Features
  - Quality Control
- Analysis Methods
  - Gumbel
  - Tn5Gaps
  - HMM
  - Re-sampling
  - Genetic Interactions
  - ANOVA
  - Normalization
  - Pathway Enrichment Analysis
  - Quality Control/TnSeq Statistics
- Console Mode Cheat-Sheet
  - Analysis Methods
  - Normalizing datasets

TRANSIT Tutorials

- Tutorial: Genetic Interactions Analysis
  - Console Mode Tutorial
  - GUI Mode Tutorial
- Tutorial: Normalize datasets
  - Adding the annotation file
  - Add .wig datasets
  - Normalize and Save
  - Normalization
- Tutorial: Export datasets
  - Adding the annotation file
  - Add .wig datasets
  - Export to IGV

TPP Manual

- TPP Overview
- Installation
- Running TPP
- Overview of Data Processing Procedure
- Statistics

Code Documentation

- transit package
  - Submodules
  - pytransit.norm_tools module
  - pytransit.stat_tools module
  - pytransit.tnseq_tools module
  - pytransit.transit_tools module
  - Module contents

- Index
- Module Index
- Search Page